<?php

namespace Drupal\fingerprint\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Form\FormBuilderInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Returns responses for fingerprint routes.
 */
class FingerprintController extends ControllerBase {

  /**
   * The form builder.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * Constructs a new FingerprintSettingsForm object.
   *
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder.
   */
  public function __construct(FormBuilderInterface $form_builder) {
    $this->formBuilder = $form_builder;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('form_builder')
    );
  }

  /**
   * Ajax json response.
   */
  public function ajaxTimeline($date = '') {
    // Current week.
    $start = strtotime('this week');
    $end = strtotime('this week +6 days');
    if (!empty($date)) {
      if (strpos($date, "-W") !== FALSE) {
        [$year, $week] = explode('-W', $date);
        $start = strtotime($year . 'W' . str_pad($week, 2, '0', STR_PAD_LEFT));
        $end = strtotime('+6 days', $start);
      }
      else {
        $month = date('Y-m', strtotime($date));
        $start = strtotime(date('Y-m-01', strtotime($month)));
        $end = strtotime(date('Y-m-t', strtotime($month)));
      }
    }
    $response = $this->getData($start, $end);
    $response['method'] = 'GET';
    $response['status'] = 200;
    return new JsonResponse($response);
  }

  /**
   * Get time data.
   *
   * {@inheritdoc}
   */
  public function getData($start, $end) {
    $groups = $result = [];
    $query = $this->entityTypeManager()->getStorage('work_time')
      ->getQuery()
      ->accessCheck(TRUE)
      ->condition('created', [$start, $end], 'BETWEEN');
    $fingerprint_ids = $query->execute();
    if ($fingerprint_ids) {
      $entityManager = $this->entityTypeManager();
      $fingerService = $entityManager->getStorage('work_time');
      $userService = $entityManager->getStorage('user');
      foreach ($fingerprint_ids as $id) {
        $entity = $fingerService->load($id);
        $uid = $entity->getOwnerId();
        if (empty($groups[$uid])) {
          $user = $userService->load($uid);
          $groups[$uid] = [
            'id' => $uid,
            'content' => empty($user) ? $entity->get('label')->value : $user->getDisplayName(),
          ];
        }
        $hour = round($entity->get('time_total')->value / 3600);
        $result[] = [
          "id" => $entity->id(),
          "content" => empty($hour) ? 'N/A' : " $hour",
          "start" => date('Y-m-d\TH:i', $entity->get('created')->value),
          "end" => date('Y-m-d\TH:i', $entity->get('stopped')->value),
          'group' => $entity->getOwnerId(),
          'title' => !empty($entity->get('field_break')->value) ? $this->t('Break %break', ['%break' => $entity->get('field_break')->value]) : '',
        ];
        /*
        if (!empty($entity->get('field_break')->value)) {
        $break = explode(',', $entity->get('field_break')->value);
        foreach ($break as $time) {
        $dateStart = date('Y-m-d', $entity->get('created')->value);
        $timeBreak = date('Y-m-d\TH:i', strtotime($dateStart . ' ' . trim($time)
        ));
        $result[] = [
        "content" => trim($time),
        "start" => $timeBreak,
        'group' => $entity->getOwnerId(),
        ];
        }
        }
         */
      }
    }
    return ['items' => $result, 'groups' => array_values($groups)];
  }

}
